==> hchiam-0.0.1.tar.gz: hchiam-0.0.1/README.md <==
Hi there! 🔍 [hchiam.com](https://hchiam.com)

Here's some GitHub stats: [resume.github.io/?hchiam](https://resume.github.io/?hchiam)

Some fun explorations: <!-- Fun stuff but also stuff I tend to refer to often. -->
[Generate form template code without typing code](https://github.com/hchiam/html-template-generator).
[Get the percent similarity between sentences](https://github.com/hchiam/text-similarity-test).
[Build super-powered Google docs](https://github.com/hchiam/learning-google-apps-script).
[Make anything draggable and editable (with keyboard accessibility in mind)](https://github.com/hchiam/draggable).
[Get automated code suggestions](https://github.com/hchiam/sourcefetch-server).
[Draw without a touchpad/pen](https://github.com/hchiam/draw-with-mouse-and-spacebar).
[Learn web accessibility](https://github.com/hchiam/web-accessibility-course-notes).
[Explore code API with AI](https://github.com/hchiam/code-explorer).
[Map out file dependencies](https://github.com/hchiam/deps).
[Scan website scripts with URLVoid via a Firefox extension](https://github.com/hchiam/urlvoid-firefox-extension).
[Get anonymous input while teaching](https://github.com/hchiam/anonymous-input).
[Learn random JS tidbits](https://github.com/hchiam/learning-js).
[Auto-generate project code/setup](https://github.com/hchiam/generator-hchiam-learning).
[Make a custom VSCode linter](https://github.com/hchiam/custom-vscode-linter).
And [learn more](https://github.com/hchiam/learning)!

<!-- <a href="https://hchiam.github.io/?can-you-find-all-the-hidden-features?">
  <img align="center" src="header.svg" width="400" height="60" alt="" onerror="this.style.display='none'"/>
</a> -->

<!--
**hchiam/hchiam** is a ✨ _special_ ✨ repository because its `README.md` (this file) appears on your GitHub profile.

Here are some ideas to get you started:

- 🔭 I’m currently working on ...
- 🌱 I’m currently learning ...
- 👯 I’m looking to collaborate on ...
- 🤔 I’m looking for help with ...
- 💬 Ask me about ...
- 📫 How to reach me: ...
- 😄 Pronouns: ...
- ⚡ Fun fact: ...
-->

==> hchiam-1.0.0.tar.gz: hchiam-1.0.0/README.md <==
Hi there! 🔍 [hchiam.com](https://hchiam.com)

Here's some GitHub stats: [resume.github.io/?hchiam](https://resume.github.io/?hchiam)

Some fun explorations: <!-- Fun stuff but also stuff I tend to refer to often. -->
[Generate form template code without typing code](https://github.com/hchiam/html-template-generator).
[Get the percent similarity between sentences](https://github.com/hchiam/text-similarity-test).
[Build super-powered Google docs](https://github.com/hchiam/learning-google-apps-script).
[Make anything draggable and editable (with keyboard accessibility in mind)](https://github.com/hchiam/draggable).
[Get automated code suggestions](https://github.com/hchiam/sourcefetch-server).
[Draw without a touchpad/pen](https://github.com/hchiam/draw-with-mouse-and-spacebar).
[Learn web accessibility](https://github.com/hchiam/web-accessibility-course-notes).
[Explore code API with AI](https://github.com/hchiam/code-explorer).
[Map out file dependencies](https://github.com/hchiam/deps).
[Scan website scripts with URLVoid via a Firefox extension](https://github.com/hchiam/urlvoid-firefox-extension).
[Get anonymous input while teaching](https://github.com/hchiam/anonymous-input).
[Learn random JS tidbits](https://github.com/hchiam/learning-js).
[Auto-generate project code/setup](https://github.com/hchiam/generator-hchiam-learning).
[Make a custom VSCode linter](https://github.com/hchiam/custom-vscode-linter).
And [learn more](https://github.com/hchiam/learning)!

Always be <a href="https://github.com/hchiam/learning"><img align="center" src="animation.svg" height="24px" alt="Learning"/></a>

<!-- <a href="https://hchiam.github.io/?can-you-find-all-the-hidden-features?">
  <img align="center" src="header.svg" width="400" height="60" alt="" onerror="this.style.display='none'"/>
</a> -->

<!-- **hchiam/hchiam** is a ✨ _special_ ✨ repository because its `README.md` (this file) appears on your GitHub profile. -->
